/* EGG - The GIMP Toolkit
 * eggpagesettings.h: Page Settings
 * Copyright (C) 2005, Red Hat, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __EGG_PAGE_SETTINGS_H__
#define __EGG_PAGE_SETTINGS_H__

#include <glib-object.h>
#include <eggpapersize.h>

G_BEGIN_DECLS

typedef struct _EggPageSettings EggPageSettings;

#define EGG_TYPE_PAGE_SETTINGS    (egg_page_settings_get_type ())
#define EGG_PAGE_SETTINGS(obj)    (G_TYPE_CHECK_INSTANCE_CAST ((obj), EGG_TYPE_PAGE_SETTINGS, EggPageSettings))
#define EGG_IS_PAGE_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), EGG_TYPE_PAGE_SETTINGS))

typedef enum {
  EGG_PAGE_ORIENTATION_PORTRAIT,
  EGG_PAGE_ORIENTATION_LANDSCAPE
} EggPageOrientation;


GType              egg_page_settings_get_type          (void);
EggPageSettings *  egg_page_settings_new               (void);
EggPageSettings *  egg_page_settings_copy              (EggPageSettings    *other);
EggPageOrientation egg_page_settings_get_orientation   (EggPageSettings    *settings);
void               egg_page_settings_set_orientation   (EggPageSettings    *settings,
							EggPageOrientation  orientation);
EggPaperSize *     egg_page_settings_get_paper_size    (EggPageSettings    *settings);
void               egg_page_settings_set_paper_size    (EggPageSettings    *settings,
							EggPaperSize        *size);

double             egg_page_settings_get_top_margin    (EggPageSettings    *settings);
void               egg_page_settings_set_top_margin    (EggPageSettings    *settings,
							double              margin);
double             egg_page_settings_get_bottom_margin (EggPageSettings    *settings);
void               egg_page_settings_set_bottom_margin (EggPageSettings    *settings,
							double              margin);
double             egg_page_settings_get_left_margin   (EggPageSettings    *settings);
void               egg_page_settings_set_left_margin   (EggPageSettings    *settings,
							double              margin);
double             egg_page_settings_get_right_margin  (EggPageSettings    *settings);
void               egg_page_settings_set_right_margin  (EggPageSettings    *settings,
							double              margin);

/* These take orientation, but not margins into consideration */
double             egg_page_settings_get_paper_width   (EggPageSettings    *settings);
double             egg_page_settings_get_paper_height  (EggPageSettings    *settings);

/* These take orientation, and margins into consideration */
double             egg_page_settings_get_page_width   (EggPageSettings    *settings);
double             egg_page_settings_get_page_height  (EggPageSettings    *settings);



/* More in here?
   paper color? paper source? scale? */

G_END_DECLS

#endif /* __EGG_PAGE_SETTINGS_H__ */
