/* EGG - The GIMP Toolkit
 * eggprintsettings.h: Print Settings
 * Copyright (C) 2005, Red Hat, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#include <pango/pangocairo.h>
#include <gtk/gtk.h>
#include "eggprint.h"
#include "testprintfileoperation.h"

static gboolean
draw_page (EggPrintOperation *operation,
	   cairo_t *cr,
	   int page_nr,
	   EggPageSettings *settings)
{
  PangoLayout *layout;
  
  if (page_nr != 0)
    return FALSE;

  cairo_rectangle (cr, 0, 0, 50, 50);
  cairo_stroke (cr);

  cairo_set_source_rgb (cr, 1.0, 0, 0);
  cairo_rectangle (cr, 20, 20, 10, 10);
  cairo_fill (cr);

  layout = pango_cairo_create_layout (cr);
  pango_layout_set_text (layout, "Hello World!", -1);

  cairo_save (cr);
  cairo_move_to (cr, 100, 100);
  pango_cairo_show_layout (cr, layout);
  cairo_restore(cr);
 
  g_object_unref (layout);
  

  return TRUE;
}

int
main (int argc, char **argv)
{
  EggPrinterSettings *settings;
  EggPaperSize *size;
  EggPrintOperation *print;
  TestPrintFileOperation *print_file;

  gtk_init (&argc, &argv);

  print = egg_print_operation_new ();
  egg_print_operation_set_pdf_target (print, "test.pdf");

  g_signal_connect (print, "draw_page", G_CALLBACK (draw_page), NULL);
  
  egg_print_operation_run (print);

  print_file = test_print_file_operation_new ("testprint.c");
  test_print_operation_set_lines_per_page (print_file, 72);
  egg_print_operation_set_pdf_target (EGG_PRINT_OPERATION (print_file), "test2.pdf");
  egg_print_operation_run (EGG_PRINT_OPERATION (print_file));
  
  return 0;
}
