#include <pango/pangocairo.h>
#include <gtk/gtk.h>
#include "testprintfileoperation.h"

G_DEFINE_TYPE (TestPrintFileOperation, test_print_file_operation, EGG_TYPE_PRINT_OPERATION)

static void
test_print_file_operation_finalize (GObject *object)
{
  TestPrintFileOperation *op = TEST_PRINT_FILE_OPERATION (object);
  
  g_free (op->filename);
  
  G_OBJECT_CLASS (test_print_file_operation_parent_class)->finalize (object);
}

static void
test_print_file_operation_init (TestPrintFileOperation *operation)
{
}

TestPrintFileOperation *
test_print_file_operation_new (const char *filename)
{
  TestPrintFileOperation *op;

  op = g_object_new (TEST_TYPE_PRINT_FILE_OPERATION, NULL);

  op->filename = g_strdup (filename);
  
  return op;
}  
  
void
test_print_operation_set_lines_per_page (TestPrintFileOperation *op,
					 int lines_per_page)
{
  op->lines_per_page = lines_per_page;
}

static void
test_print_file_operation_begin_print (EggPrintOperation *operation)
{
  TestPrintFileOperation *op = TEST_PRINT_FILE_OPERATION (operation);
  char *contents;
  int i;

  g_file_get_contents (op->filename,
		       &contents,
		       NULL, NULL);

  op->lines = g_strsplit (contents, "\n", 0);
  g_free (contents);

  i = 0;
  while (op->lines[i] != NULL)
    i++;
  
  op->num_lines = i;

  egg_print_operation_set_nr_of_pages (operation, (op->num_lines - 1) / op->lines_per_page + 1);
}

#define MM_PER_INCH 25.4
#define POINTS_PER_INCH 72

static double
mm_to_points (double mm)
{
  return mm * POINTS_PER_INCH/MM_PER_INCH;
}

static gboolean
test_print_file_operation_draw_page (EggPrintOperation *operation,
				     cairo_t *cr,
				     int page_nr,
				     EggPageSettings *page_settings)
{
  PangoLayout *layout;
  TestPrintFileOperation *op = TEST_PRINT_FILE_OPERATION (operation);
  double height;
  int line, i;
  PangoFontDescription *desc;

  layout = pango_cairo_create_layout (cr);

  height = egg_page_settings_get_page_height (page_settings);

  desc = pango_font_description_from_string ("mono");
  pango_font_description_set_size (desc, (height/op->lines_per_page) * PANGO_SCALE);
  pango_layout_set_font_description (layout, desc);
  
  cairo_move_to (cr, 0, 0);
  line = page_nr * op->lines_per_page;
  for (i = 0; i < op->lines_per_page && line < op->num_lines; i++, line++) {
    pango_layout_set_text (layout, op->lines[line], -1);
    pango_cairo_show_layout (cr, layout);
    cairo_rel_move_to (cr, 0, height / op->lines_per_page);
  }
  return TRUE;
}

static void
test_print_file_operation_end_print (EggPrintOperation *operation)
{
  TestPrintFileOperation *op = TEST_PRINT_FILE_OPERATION (operation);
  g_strfreev (op->lines);
}



static void
test_print_file_operation_class_init (TestPrintFileOperationClass *class)
{
  GObjectClass *gobject_class = (GObjectClass *)class;
  EggPrintOperationClass *print_class = (EggPrintOperationClass *)class;

  gobject_class->finalize = test_print_file_operation_finalize;
  print_class->begin_print = test_print_file_operation_begin_print;
  print_class->draw_page = test_print_file_operation_draw_page;
  print_class->end_print = test_print_file_operation_end_print;
  
}


